inheritance — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# inheritance

Controls related to visualizing object hierarchy

class `camelot.view.controls.inheritance.` `SubclassDialog`(parent, admin)

  A dialog requesting the user to select a subclass

class `camelot.view.controls.inheritance.` `SubclassTree`(admin, parent)

  Widget to select subclasses of a certain entity, where the subclasses are represented in a tree

  emits subclassClicked when a subclass has been selected

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus